==> netams-3.2.1.tar.gz: netams-3.2.1/src/versions.sh <==
#!/bin/sh
# $Id: versions.sh,v 1.14 2005/01/07 00:22:50 anton Exp $ 

build_hostname=`uname -n`
current_v=`cat versions_build.dat`
next_v=$current_v
next_v_l=0;

os=`uname`
if [ $os = "SunOS" ] 
then
	sh=ksh
else 
	sh=sh
fi

if [ ! -d ../private ]; then
	if [ -r versions_build_local.dat ]; then
		current_v_l=`cat versions_build_local.dat`
	else
		current_v_l=0;
	fi
		
	next_v_l=`$sh -c "echo $((1+$current_v_l))"`
	echo $next_v_l > versions_build_local.dat

else
	next_v=`$sh -c "echo $((1+$current_v))"`
	next_v_l=0;
	rm -rf versions_build_local.dat 
	echo $next_v > versions_build.dat
fi
	
build_date=`date`
if [ $os = "SunOS" ]
then
	build_person=`id |cut -f 1 -d ' '|cut -f 2 -d '('|sed s/\)//`@`uname -n`
else 
	build_person=`whoami`@`uname -n`
fi

echo "const unsigned int aaa_fw_build_version=$next_v;" > versions_build.c
echo "const unsigned int aaa_fw_build_version_local=$next_v_l;" >> versions_build.c
echo "const char aaa_fw_build_time[]=\"$build_date\";" >> versions_build.c
echo "const char aaa_fw_build_person[]=\"$build_person\";" >> versions_build.c
if [ "$1" != "" ]; then
	echo "const char path_to_config[]=\"$1\";" >> versions_build.c
	else 
	echo "const char path_to_config[]=\"/usr/local/etc/netams.cfg\";" >> versions_build.c
fi
if [ "$2" != "" ]; then
	echo "const char path_to_log[]=\"$2\";" >> versions_build.c
	else 
	echo "const char path_to_log[]=\"/var/log/netams.log\";" >> versions_build.c
fi
echo "linking for version $next_v.$next_v_l"
rm -rf versions_build.o
gcc -c versions_build.c

==> netams-3.4.1rc1.tar.gz: netams-3.4.1rc1/src/versions.sh <==
#!/bin/sh
# $Id: versions.sh,v 1.16 2008-01-03 12:44:53 anton Exp $

build_hostname=`uname -n`
current_v=`cat versions_build.dat`
next_v=$current_v
next_v_l=0;

os=`uname`
if [ $os = "SunOS" ]
then
	sh=ksh
else
	sh=sh
fi

if [ ! -d ../private ]; then
	if [ -r versions_build_local.dat ]; then
		current_v_l=`cat versions_build_local.dat`
	else
		current_v_l=0;
	fi

	next_v_l=`$sh -c "echo $((1+$current_v_l))"`
	echo $next_v_l > versions_build_local.dat

else
	next_v=`$sh -c "echo $((1+$current_v))"`
	next_v_l=0;
	rm -rf versions_build_local.dat
	echo $next_v > versions_build.dat
fi

build_date=`date`
if [ $os = "SunOS" ]
then
	build_person=`id |cut -f 1 -d ' '|cut -f 2 -d '('|sed s/\)//`@`uname -n`
else
	build_person=`whoami`@`uname -n`
fi

echo "const unsigned int aaa_fw_build_version=$next_v;" > versions_build.c
echo "const unsigned int aaa_fw_build_version_local=$next_v_l;" >> versions_build.c
echo "const char aaa_fw_build_time[]=\"$build_date\";" >> versions_build.c
echo "const char aaa_fw_build_person[]=\"$build_person\";" >> versions_build.c
if [ "$1" != "" ]; then
	echo "const char path_to_config[]=\"$1\";" >> versions_build.c
	else
	echo "const char path_to_config[]=\"/usr/local/etc/netams.conf\";" >> versions_build.c
fi
if [ "$2" != "" ]; then
	echo "const char path_to_log[]=\"$2\";" >> versions_build.c
	else
	echo "const char path_to_log[]=\"/var/log/netams.log\";" >> versions_build.c
fi
echo "linking for version $next_v.$next_v_l"
rm -rf versions_build.o
gcc -c versions_build.c
